==> hpmgmt-7.2.0-vmware.tgz: opt/hp/hpsmh/data/htdocs/hmastor/help/helpmap.js <==
// RCSfile: helpmap.js Revision: 1.1 $
// (C) Copyright 2003 Hewlett-Packard Development Company, L.P.
addMapping('ms-dabox.php', null, 'ima00042.htm', null);
addMapping('ms-dactl.php', null, 'ima00042.htm', null);
addMapping('ms-dalog.php', null, 'ima00042.htm', null);
addMapping('ms-damnu.php', null, 'ima00042.htm', null);
addMapping('ms-daphy.php', null, 'ima00042.htm', null);
addMapping('ms-dtape.php', null, 'ima00042.htm', null);
addMapping('ms-dtlib.php', null, 'ima00042.htm', null);
addMapping('ms-idctl.php', null, 'ima00046.htm', null);
addMapping('ms-idmnu.php', null, 'ima00046.htm', null);
addMapping('ms-idphy.php', null, 'ima00046.htm', null);
addMapping('ms-idlog.php', null, 'ima00046.htm', null);
addMapping('ms-scmnu.php', null, 'ima00041.htm', null);
addMapping('ms-scsi.php',  null, 'ima00041.htm', null);
addMapping('ms-sctl.php',  null, 'ima00041.htm', null);
addMapping('ms-fccon.php', null, 'ima00043.htm', null);
addMapping('ms-fccnt.php', null, 'ima00043.htm', null);
addMapping('ms-fcctl.php', null, 'ima00043.htm', null);
addMapping('ms-fclog.php', null, 'ima00043.htm', null);
addMapping('ms-fcmnu.php', null, 'ima00043.htm', null);
addMapping('ms-fcphy.php', null, 'ima00043.htm', null);
addMapping('ms-fcss.php',  null, 'ima00043.htm', null);
addMapping('ms-fces.php',  null, 'ima00043.htm', null);
addMapping('ms-fcsw.php',  null, 'ima00043.htm', null);
addMapping('ms-raids.php', null, 'ima00043.htm', null);
addMapping('ms-ftape.php', null, 'ima00044.htm', null);
addMapping('ms-ftctl.php', null, 'ima00044.htm', null);
addMapping('ms-ftlib.php', null, 'ima00044.htm', null);
addMapping('ms-ftmnu.php', null, 'ima00044.htm', null);

==> hpmgmt-7.4.0b-vmware.tgz: opt/hp/hpsmh/data/htdocs/hmastor/help/helpmap.js <==
// RCSfile: helpmap.js Revision: 1.3 $
// (C) Copyright 2003 Hewlett-Packard Development Company, L.P.
addMapping('ms-dabox.php', null, 'ima00042.htm', null);
addMapping('ms-dactl.php', null, 'ima00042.htm', null);
addMapping('ms-dalog.php', null, 'ima00042.htm', null);
addMapping('ms-damnu.php', null, 'ima00042.htm', null);
addMapping('ms-daphy.php', null, 'ima00042.htm', null);
addMapping('ms-dtape.php', null, 'ima00042.htm', null);
addMapping('ms-dtlib.php', null, 'ima00042.htm', null);
addMapping('ms-idctl.php', null, 'ima00046.htm', null);
addMapping('ms-idmnu.php', null, 'ima00046.htm', null);
addMapping('ms-idphy.php', null, 'ima00046.htm', null);
addMapping('ms-idlog.php', null, 'ima00046.htm', null);
addMapping('ms-scmnu.php', null, 'ima00041.htm', null);
addMapping('ms-scsi.php',  null, 'ima00041.htm', null);
addMapping('ms-sctl.php',  null, 'ima00041.htm', null);
addMapping('ms-fccon.php', null, 'ima00043.htm', null);
addMapping('ms-fccnt.php', null, 'ima00043.htm', null);
addMapping('ms-fcctl.php', null, 'ima00043.htm', null);
addMapping('ms-fclog.php', null, 'ima00043.htm', null);
addMapping('ms-fcmnu.php', null, 'ima00043.htm', null);
addMapping('ms-fcphy.php', null, 'ima00043.htm', null);
addMapping('ms-fcss.php',  null, 'ima00043.htm', null);
addMapping('ms-fces.php',  null, 'ima00043.htm', null);
addMapping('ms-fcsw.php',  null, 'ima00043.htm', null);
addMapping('ms-raids.php', null, 'ima00043.htm', null);
addMapping('ms-ftape.php', null, 'ima00044.htm', null);
addMapping('ms-ftctl.php', null, 'ima00044.htm', null);
addMapping('ms-ftlib.php', null, 'ima00044.htm', null);
addMapping('ms-ftmnu.php', null, 'ima00044.htm', null);
addMapping('ms-iscmn.php', null, 'ima00047.htm', null);
addMapping('ms-iscxn.php', null, 'ima00047.htm', null);
addMapping('ms-isinit.php', null, 'ima00047.htm', null);
addMapping('ms-ismnu.php', null, 'ima00047.htm', null);
addMapping('ms-isnod.php', null, 'ima00047.htm', null);
addMapping('ms-isssn.php', null, 'ima00047.htm', null);
addMapping('ms-isins.php', null, 'ima00047.htm', null);
addMapping('ms-samnu.php', null, 'ima00048.htm', null);
addMapping('ms-sahba.php', null, 'ima00048.htm', null);
addMapping('ms-saphy.php', null, 'ima00048.htm', null);
addMapping('ms-salog.php', null, 'ima00048.htm', null);
